@@ -44,24 +44,26 @@
 #include "extnsionst.h"
 #include "xfixes.h"
 #include "dri2.h"
+#include "dri2int.h"
 #include "protocol-versions.h"
 
-/* The only xf86 include */
+/* The only xf86 includes */
 #include "xf86Module.h"
+#include "xf86Extensions.h"
+
+static int DRI2EventBase;
 
-static ExtensionEntry	*dri2Extension;
-extern Bool DRI2ModuleSetup(void);
 
 static Bool
 validDrawable(ClientPtr client, XID drawable, Mask access_mode,
-	      DrawablePtr *pDrawable, int *status)
+              DrawablePtr *pDrawable, int *status)
 {
     *status = dixLookupDrawable(pDrawable, drawable, client,
-				M_DRAWABLE_WINDOW | M_DRAWABLE_PIXMAP,
-				access_mode);
+                                M_DRAWABLE_WINDOW | M_DRAWABLE_PIXMAP,
+                                access_mode);
     if (*status != Success) {
-	client->errorValue = drawable;
-	return FALSE;
+        client->errorValue = drawable;
+        return FALSE;
     }
 
     return TRUE;
@@ -71,23 +73,24 @@ static int
 ProcDRI2QueryVersion(ClientPtr client)
 {
     REQUEST(xDRI2QueryVersionReq);
-    xDRI2QueryVersionReply rep;
+    xDRI2QueryVersionReply rep = {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = 0,
+        .majorVersion = dri2_major,
+        .minorVersion = dri2_minor
+    };
 
     if (client->swapped)
-	swaps(&stuff->length);
+        swaps(&stuff->length);
 
     REQUEST_SIZE_MATCH(xDRI2QueryVersionReq);
-    rep.type = X_Reply;
-    rep.length = 0;
-    rep.sequenceNumber = client->sequence;
-    rep.majorVersion = dri2_major;
-    rep.minorVersion = dri2_minor;
 
     if (client->swapped) {
-	swaps(&rep.sequenceNumber);
-	swapl(&rep.length);
-	swapl(&rep.majorVersion);
-	swapl(&rep.minorVersion);
+        swaps(&rep.sequenceNumber);
+        swapl(&rep.length);
+        swapl(&rep.majorVersion);
+        swapl(&rep.minorVersion);
     }
 
     WriteToClient(client, sizeof(xDRI2QueryVersionReply), &rep);
@@ -99,7 +102,13 @@ static int
 ProcDRI2Connect(ClientPtr client)
 {
     REQUEST(xDRI2ConnectReq);
-    xDRI2ConnectReply rep;
+    xDRI2ConnectReply rep = {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = 0,
+        .driverNameLength = 0,
+        .deviceNameLength = 0
+    };
     DrawablePtr pDraw;
     int fd, status;
     const char *driverName;
@@ -107,23 +116,17 @@ ProcDRI2Connect(ClientPtr client)
 
     REQUEST_SIZE_MATCH(xDRI2ConnectReq);
     if (!validDrawable(client, stuff->window, DixGetAttrAccess,
-		       &pDraw, &status))
-	return status;
-    
-    rep.type = X_Reply;
-    rep.length = 0;
-    rep.sequenceNumber = client->sequence;
-    rep.driverNameLength = 0;
-    rep.deviceNameLength = 0;
+                       &pDraw, &status))
+        return status;
 
-    if (!DRI2Connect(pDraw->pScreen,
-		     stuff->driverType, &fd, &driverName, &deviceName))
-	goto fail;
+    if (!DRI2Connect(client, pDraw->pScreen,
+                     stuff->driverType, &fd, &driverName, &deviceName))
+        goto fail;
 
     rep.driverNameLength = strlen(driverName);
     rep.deviceNameLength = strlen(deviceName);
     rep.length = (rep.driverNameLength + 3) / 4 +
-	    (rep.deviceNameLength + 3) / 4;
+        (rep.deviceNameLength + 3) / 4;
 
  fail:
     WriteToClient(client, sizeof(xDRI2ConnectReply), &rep);
@@ -143,13 +146,15 @@ ProcDRI2Authenticate(ClientPtr client)
 
     REQUEST_SIZE_MATCH(xDRI2AuthenticateReq);
     if (!validDrawable(client, stuff->window, DixGetAttrAccess,
-		       &pDraw, &status))
-	return status;
+                       &pDraw, &status))
+        return status;
 
-    rep.type = X_Reply;
-    rep.sequenceNumber = client->sequence;
-    rep.length = 0;
-    rep.authenticated = DRI2Authenticate(pDraw->pScreen, stuff->magic);
+    rep = (xDRI2AuthenticateReply) {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = 0,
+        .authenticated = DRI2Authenticate(client, pDraw->pScreen, stuff->magic)
+    };
     WriteToClient(client, sizeof(xDRI2AuthenticateReply), &rep);
 
     return Success;
@@ -158,13 +163,13 @@ ProcDRI2Authenticate(ClientPtr client)
 static void
 DRI2InvalidateBuffersEvent(DrawablePtr pDraw, void *priv, XID id)
 {
-    xDRI2InvalidateBuffers event;
     ClientPtr client = priv;
+    xDRI2InvalidateBuffers event = {
+        .type = DRI2EventBase + DRI2_InvalidateBuffers,
+        .drawable = id
+    };
 
-    event.type = DRI2EventBase + DRI2_InvalidateBuffers;
-    event.drawable = id;
-
-    WriteEventsToClient(client, 1, (xEvent *)&event);
+    WriteEventsToClient(client, 1, (xEvent *) &event);
 }
 
 static int
@@ -177,13 +182,13 @@ ProcDRI2CreateDrawable(ClientPtr client)
     REQUEST_SIZE_MATCH(xDRI2CreateDrawableReq);
 
     if (!validDrawable(client, stuff->drawable, DixAddAccess,
-		       &pDrawable, &status))
-	return status;
+                       &pDrawable, &status))
+        return status;
 
     status = DRI2CreateDrawable(client, pDrawable, stuff->drawable,
-				DRI2InvalidateBuffersEvent, client);
+                                DRI2InvalidateBuffersEvent, client);
     if (status != Success)
-	return status;
+        return status;
 
     return Success;
 }
@@ -197,64 +202,64 @@ ProcDRI2DestroyDrawable(ClientPtr client)
 
     REQUEST_SIZE_MATCH(xDRI2DestroyDrawableReq);
     if (!validDrawable(client, stuff->drawable, DixRemoveAccess,
-		       &pDrawable, &status))
-	return status;
+                       &pDrawable, &status))
+        return status;
 
     return Success;
 }
 
-
 static int
 send_buffers_reply(ClientPtr client, DrawablePtr pDrawable,
-		   DRI2BufferPtr *buffers, int count, int width, int height)
+                   DRI2BufferPtr * buffers, int count, int width, int height)
 {
     xDRI2GetBuffersReply rep;
     int skip = 0;
     int i;
 
     if (buffers == NULL)
-	    return BadAlloc;
+        return BadAlloc;
 
     if (pDrawable->type == DRAWABLE_WINDOW) {
-	for (i = 0; i < count; i++) {
-	    /* Do not send the real front buffer of a window to the client.
-	     */
-	    if (buffers[i]->attachment == DRI2BufferFrontLeft) {
-		skip++;
-		continue;
-	    }
-	}
+        for (i = 0; i < count; i++) {
+            /* Do not send the real front buffer of a window to the client.
+             */
+            if (buffers[i]->attachment == DRI2BufferFrontLeft) {
+                skip++;
+                continue;
+            }
+        }
     }
 
-    rep.type = X_Reply;
-    rep.length = (count - skip) * sizeof(xDRI2Buffer) / 4;
-    rep.sequenceNumber = client->sequence;
-    rep.width = width;
-    rep.height = height;
-    rep.count = count - skip;
+    rep = (xDRI2GetBuffersReply) {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = (count - skip) * sizeof(xDRI2Buffer) / 4,
+        .width = width,
+        .height = height,
+        .count = count - skip
+    };
     WriteToClient(client, sizeof(xDRI2GetBuffersReply), &rep);
 
     for (i = 0; i < count; i++) {
-	xDRI2Buffer buffer;
+        xDRI2Buffer buffer;
 
-	/* Do not send the real front buffer of a window to the client.
-	 */
-	if ((pDrawable->type == DRAWABLE_WINDOW)
-	    && (buffers[i]->attachment == DRI2BufferFrontLeft)) {
-	    continue;
-	}
+        /* Do not send the real front buffer of a window to the client.
+         */
+        if ((pDrawable->type == DRAWABLE_WINDOW)
+            && (buffers[i]->attachment == DRI2BufferFrontLeft)) {
+            continue;
+        }
 
-	buffer.attachment = buffers[i]->attachment;
-	buffer.name = buffers[i]->name;
-	buffer.pitch = buffers[i]->pitch;
-	buffer.cpp = buffers[i]->cpp;
-	buffer.flags = buffers[i]->flags;
-	WriteToClient(client, sizeof(xDRI2Buffer), &buffer);
+        buffer.attachment = buffers[i]->attachment;
+        buffer.name = buffers[i]->name;
+        buffer.pitch = buffers[i]->pitch;
+        buffer.cpp = buffers[i]->cpp;
+        buffer.flags = buffers[i]->flags;
+        WriteToClient(client, sizeof(xDRI2Buffer), &buffer);
     }
     return Success;
 }
 
-
 static int
 ProcDRI2GetBuffers(ClientPtr client)
 {
@@ -266,16 +271,15 @@ ProcDRI2GetBuffers(ClientPtr client)
 
     REQUEST_FIXED_SIZE(xDRI2GetBuffersReq, stuff->count * 4);
     if (!validDrawable(client, stuff->drawable, DixReadAccess | DixWriteAccess,
-		       &pDrawable, &status))
-	return status;
+                       &pDrawable, &status))
+        return status;
 
     if (DRI2ThrottleClient(client, pDrawable))
-	return Success;
+        return Success;
 
     attachments = (unsigned int *) &stuff[1];
     buffers = DRI2GetBuffers(pDrawable, &width, &height,
-			     attachments, stuff->count, &count);
-
+                             attachments, stuff->count, &count);
 
     return send_buffers_reply(client, pDrawable, buffers, count, width, height);
 
@@ -292,15 +296,15 @@ ProcDRI2GetBuffersWithFormat(ClientPtr client)
 
     REQUEST_FIXED_SIZE(xDRI2GetBuffersReq, stuff->count * (2 * 4));
     if (!validDrawable(client, stuff->drawable, DixReadAccess | DixWriteAccess,
-		       &pDrawable, &status))
-	return status;
+                       &pDrawable, &status))
+        return status;
 
     if (DRI2ThrottleClient(client, pDrawable))
-	return Success;
+        return Success;
 
     attachments = (unsigned int *) &stuff[1];
     buffers = DRI2GetBuffersWithFormat(pDrawable, &width, &height,
-				       attachments, stuff->count, &count);
+                                       attachments, stuff->count, &count);
 
     return send_buffers_reply(client, pDrawable, buffers, count, width, height);
 }
@@ -317,14 +321,14 @@ ProcDRI2CopyRegion(ClientPtr client)
     REQUEST_SIZE_MATCH(xDRI2CopyRegionReq);
 
     if (!validDrawable(client, stuff->drawable, DixWriteAccess,
-		       &pDrawable, &status))
-	return status;
+                       &pDrawable, &status))
+        return status;
 
     VERIFY_REGION(pRegion, stuff->region, client, DixReadAccess);
 
     status = DRI2CopyRegion(pDrawable, pRegion, stuff->dest, stuff->src);
     if (status != Success)
-	return status;
+        return status;
 
     /* CopyRegion needs to be a round trip to make sure the X server
      * queues the swap buffer rendering commands before the DRI client
@@ -333,9 +337,11 @@ ProcDRI2CopyRegion(ClientPtr client)
      * that yet.
      */
 
-    rep.type = X_Reply;
-    rep.length = 0;
-    rep.sequenceNumber = client->sequence;
+    rep = (xDRI2CopyRegionReply) {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = 0
+    };
 
     WriteToClient(client, sizeof(xDRI2CopyRegionReply), &rep);
 
@@ -343,7 +349,7 @@ ProcDRI2CopyRegion(ClientPtr client)
 }
 
 static void
-load_swap_reply(xDRI2SwapBuffersReply *rep, CARD64 sbc)
+load_swap_reply(xDRI2SwapBuffersReply * rep, CARD64 sbc)
 {
     rep->swap_hi = sbc >> 32;
     rep->swap_lo = sbc & 0xffffffff;
@@ -352,33 +358,37 @@ load_swap_reply(xDRI2SwapBuffersReply *rep, CARD64 sbc)
 static CARD64
 vals_to_card64(CARD32 lo, CARD32 hi)
 {
-    return (CARD64)hi << 32 | lo;
+    return (CARD64) hi << 32 | lo;
 }
 
 static void
 DRI2SwapEvent(ClientPtr client, void *data, int type, CARD64 ust, CARD64 msc,
-	      CARD32 sbc)
+              CARD32 sbc)
 {
-    xDRI2BufferSwapComplete2 event;
     DrawablePtr pDrawable = data;
+    xDRI2BufferSwapComplete2 event = {
+        .type = DRI2EventBase + DRI2_BufferSwapComplete,
+        .event_type = type,
+        .drawable = pDrawable->id,
+        .ust_hi = (CARD64) ust >> 32,
+        .ust_lo = ust & 0xffffffff,
+        .msc_hi = (CARD64) msc >> 32,
+        .msc_lo = msc & 0xffffffff,
+        .sbc = sbc
+    };
 
-    event.type = DRI2EventBase + DRI2_BufferSwapComplete;
-    event.event_type = type;
-    event.drawable = pDrawable->id;
-    event.ust_hi = (CARD64)ust >> 32;
-    event.ust_lo = ust & 0xffffffff;
-    event.msc_hi = (CARD64)msc >> 32;
-    event.msc_lo = msc & 0xffffffff;
-    event.sbc = sbc;
-
-    WriteEventsToClient(client, 1, (xEvent *)&event);
+    WriteEventsToClient(client, 1, (xEvent *) &event);
 }
 
 static int
 ProcDRI2SwapBuffers(ClientPtr client)
 {
     REQUEST(xDRI2SwapBuffersReq);
-    xDRI2SwapBuffersReply rep;
+    xDRI2SwapBuffersReply rep = {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = 0
+    };
     DrawablePtr pDrawable;
     CARD64 target_msc, divisor, remainder, swap_target;
     int status;
@@ -386,28 +396,25 @@ ProcDRI2SwapBuffers(ClientPtr client)
     REQUEST_SIZE_MATCH(xDRI2SwapBuffersReq);
 
     if (!validDrawable(client, stuff->drawable,
-		       DixReadAccess | DixWriteAccess, &pDrawable, &status))
-	return status;
+                       DixReadAccess | DixWriteAccess, &pDrawable, &status))
+        return status;
 
     /*
      * Ensures an out of control client can't exhaust our swap queue, and
      * also orders swaps.
      */
     if (DRI2ThrottleClient(client, pDrawable))
-	return Success;
+        return Success;
 
     target_msc = vals_to_card64(stuff->target_msc_lo, stuff->target_msc_hi);
     divisor = vals_to_card64(stuff->divisor_lo, stuff->divisor_hi);
     remainder = vals_to_card64(stuff->remainder_lo, stuff->remainder_hi);
 
     status = DRI2SwapBuffers(client, pDrawable, target_msc, divisor, remainder,
-			     &swap_target, DRI2SwapEvent, pDrawable);
+                             &swap_target, DRI2SwapEvent, pDrawable);
     if (status != Success)
-	return BadDrawable;
+        return BadDrawable;
 
-    rep.type = X_Reply;
-    rep.length = 0;
-    rep.sequenceNumber = client->sequence;
     load_swap_reply(&rep, swap_target);
 
     WriteToClient(client, sizeof(xDRI2SwapBuffersReply), &rep);
@@ -416,7 +423,7 @@ ProcDRI2SwapBuffers(ClientPtr client)
 }
 
 static void
-load_msc_reply(xDRI2MSCReply *rep, CARD64 ust, CARD64 msc, CARD64 sbc)
+load_msc_reply(xDRI2MSCReply * rep, CARD64 ust, CARD64 msc, CARD64 sbc)
 {
     rep->ust_hi = ust >> 32;
     rep->ust_lo = ust & 0xffffffff;
@@ -430,7 +437,11 @@ static int
 ProcDRI2GetMSC(ClientPtr client)
 {
     REQUEST(xDRI2GetMSCReq);
-    xDRI2MSCReply rep;
+    xDRI2MSCReply rep = {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = 0
+    };
     DrawablePtr pDrawable;
     CARD64 ust, msc, sbc;
     int status;
@@ -438,16 +449,13 @@ ProcDRI2GetMSC(ClientPtr client)
     REQUEST_SIZE_MATCH(xDRI2GetMSCReq);
 
     if (!validDrawable(client, stuff->drawable, DixReadAccess, &pDrawable,
-		       &status))
-	return status;
+                       &status))
+        return status;
 
     status = DRI2GetMSC(pDrawable, &ust, &msc, &sbc);
     if (status != Success)
-	return status;
+        return status;
 
-    rep.type = X_Reply;
-    rep.length = 0;
-    rep.sequenceNumber = client->sequence;
     load_msc_reply(&rep, ust, msc, sbc);
 
     WriteToClient(client, sizeof(xDRI2MSCReply), &rep);
@@ -468,8 +476,8 @@ ProcDRI2WaitMSC(ClientPtr client)
     REQUEST_SIZE_MATCH(xDRI2WaitMSCReq);
 
     if (!validDrawable(client, stuff->drawable, DixReadAccess, &pDrawable,
-		       &status))
-	return status;
+                       &status))
+        return status;
 
     target = vals_to_card64(stuff->target_msc_lo, stuff->target_msc_hi);
     divisor = vals_to_card64(stuff->divisor_lo, stuff->divisor_hi);
@@ -477,7 +485,7 @@ ProcDRI2WaitMSC(ClientPtr client)
 
     status = DRI2WaitMSC(client, pDrawable, target, divisor, remainder);
     if (status != Success)
-	return status;
+        return status;
 
     return Success;
 }
@@ -485,11 +493,12 @@ ProcDRI2WaitMSC(ClientPtr client)
 int
 ProcDRI2WaitMSCReply(ClientPtr client, CARD64 ust, CARD64 msc, CARD64 sbc)
 {
-    xDRI2MSCReply rep;
+    xDRI2MSCReply rep = {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = 0
+    };
 
-    rep.type = X_Reply;
-    rep.length = 0;
-    rep.sequenceNumber = client->sequence;
     load_msc_reply(&rep, ust, msc, sbc);
 
     WriteToClient(client, sizeof(xDRI2MSCReply), &rep);
@@ -509,8 +518,8 @@ ProcDRI2SwapInterval(ClientPtr client)
     REQUEST_SIZE_MATCH(xDRI2SwapIntervalReq);
 
     if (!validDrawable(client, stuff->drawable, DixReadAccess | DixWriteAccess,
-		       &pDrawable, &status))
-	return status;
+                       &pDrawable, &status))
+        return status;
 
     DRI2SwapInterval(pDrawable, stuff->interval);
 
@@ -528,8 +537,8 @@ ProcDRI2WaitSBC(ClientPtr client)
     REQUEST_SIZE_MATCH(xDRI2WaitSBCReq);
 
     if (!validDrawable(client, stuff->drawable, DixReadAccess, &pDrawable,
-		       &status))
-	return status;
+                       &status))
+        return status;
 
     target = vals_to_card64(stuff->target_sbc_lo, stuff->target_sbc_hi);
     status = DRI2WaitSBC(client, pDrawable, target);
@@ -538,45 +547,79 @@ ProcDRI2WaitSBC(ClientPtr client)
 }
 
 static int
-ProcDRI2Dispatch (ClientPtr client)
+ProcDRI2GetParam(ClientPtr client)
+{
+    REQUEST(xDRI2GetParamReq);
+    xDRI2GetParamReply rep = {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = 0
+    };
+    DrawablePtr pDrawable;
+    CARD64 value;
+    int status;
+
+    REQUEST_SIZE_MATCH(xDRI2GetParamReq);
+
+    if (!validDrawable(client, stuff->drawable, DixReadAccess,
+                       &pDrawable, &status))
+        return status;
+
+    status = DRI2GetParam(client, pDrawable, stuff->param,
+                          &rep.is_param_recognized, &value);
+    rep.value_hi = value >> 32;
+    rep.value_lo = value & 0xffffffff;
+
+    if (status != Success)
+        return status;
+
+    WriteToClient(client, sizeof(xDRI2GetParamReply), &rep);
+
+    return status;
+}
+
+static int
+ProcDRI2Dispatch(ClientPtr client)
 {
     REQUEST(xReq);
-    
+
     switch (stuff->data) {
     case X_DRI2QueryVersion:
-	return ProcDRI2QueryVersion(client);
+        return ProcDRI2QueryVersion(client);
     }
 
     if (!LocalClient(client))
-	return BadRequest;
+        return BadRequest;
 
     switch (stuff->data) {
     case X_DRI2Connect:
-	return ProcDRI2Connect(client);
+        return ProcDRI2Connect(client);
     case X_DRI2Authenticate:
-	return ProcDRI2Authenticate(client);
+        return ProcDRI2Authenticate(client);
     case X_DRI2CreateDrawable:
-	return ProcDRI2CreateDrawable(client);
+        return ProcDRI2CreateDrawable(client);
     case X_DRI2DestroyDrawable:
-	return ProcDRI2DestroyDrawable(client);
+        return ProcDRI2DestroyDrawable(client);
     case X_DRI2GetBuffers:
-	return ProcDRI2GetBuffers(client);
+        return ProcDRI2GetBuffers(client);
     case X_DRI2CopyRegion:
-	return ProcDRI2CopyRegion(client);
+        return ProcDRI2CopyRegion(client);
     case X_DRI2GetBuffersWithFormat:
-	return ProcDRI2GetBuffersWithFormat(client);
+        return ProcDRI2GetBuffersWithFormat(client);
     case X_DRI2SwapBuffers:
-	return ProcDRI2SwapBuffers(client);
+        return ProcDRI2SwapBuffers(client);
     case X_DRI2GetMSC:
-	return ProcDRI2GetMSC(client);
+        return ProcDRI2GetMSC(client);
     case X_DRI2WaitMSC:
-	return ProcDRI2WaitMSC(client);
+        return ProcDRI2WaitMSC(client);
     case X_DRI2WaitSBC:
-	return ProcDRI2WaitSBC(client);
+        return ProcDRI2WaitSBC(client);
     case X_DRI2SwapInterval:
-	return ProcDRI2SwapInterval(client);
+        return ProcDRI2SwapInterval(client);
+    case X_DRI2GetParam:
+        return ProcDRI2GetParam(client);
     default:
-	return BadRequest;
+        return BadRequest;
     }
 }
 
@@ -584,25 +627,29 @@ static int
 SProcDRI2Connect(ClientPtr client)
 {
     REQUEST(xDRI2ConnectReq);
-    xDRI2ConnectReply rep;
+    xDRI2ConnectReply rep = {
+        .type = X_Reply,
+        .sequenceNumber = client->sequence,
+        .length = 0,
+        .driverNameLength = 0,
+        .deviceNameLength = 0
+    };
 
     /* If the client is swapped, it's not local.  Talk to the hand. */
 
     swaps(&stuff->length);
     if (sizeof(*stuff) / 4 != client->req_len)
-	return BadLength;
+        return BadLength;
 
-    rep.sequenceNumber = client->sequence;
     swaps(&rep.sequenceNumber);
-    rep.length = 0;
-    rep.driverNameLength = 0;
-    rep.deviceNameLength = 0;
+
+    WriteToClient(client, sizeof(xDRI2ConnectReply), &rep);
 
     return Success;
 }
 
 static int
-SProcDRI2Dispatch (ClientPtr client)
+SProcDRI2Dispatch(ClientPtr client)
 {
     REQUEST(xReq);
 
@@ -610,41 +657,28 @@ SProcDRI2Dispatch (ClientPtr client)
      * Only local clients are allowed DRI access, but remote clients
      * still need these requests to find out cleanly.
      */
-    switch (stuff->data)
-    {
+    switch (stuff->data) {
     case X_DRI2QueryVersion:
-	return ProcDRI2QueryVersion(client);
+        return ProcDRI2QueryVersion(client);
     case X_DRI2Connect:
-	return SProcDRI2Connect(client);
+        return SProcDRI2Connect(client);
     default:
-	return BadRequest;
+        return BadRequest;
     }
 }
 
-int DRI2EventBase;
-
-static void
+void
 DRI2ExtensionInit(void)
 {
+    ExtensionEntry *dri2Extension;
+
     dri2Extension = AddExtension(DRI2_NAME,
-				 DRI2NumberEvents,
-				 DRI2NumberErrors,
-				 ProcDRI2Dispatch,
-				 SProcDRI2Dispatch,
-				 NULL,
-				 StandardMinorOpcode);
+                                 DRI2NumberEvents,
+                                 DRI2NumberErrors,
+                                 ProcDRI2Dispatch,
+                                 SProcDRI2Dispatch, NULL, StandardMinorOpcode);
 
     DRI2EventBase = dri2Extension->eventBase;
 
     DRI2ModuleSetup();
 }
-
-extern Bool noDRI2Extension;
-
-_X_HIDDEN ExtensionModule dri2ExtensionModule = {
-    DRI2ExtensionInit,
-    DRI2_NAME,
-    &noDRI2Extension,
-    NULL,
-    NULL
-};
